@@ -101,7 +101,6 @@
 int 
 main(int argc,char **argv)
 {
-  nco_bool CNV_CCM_CCSM_CF;
   nco_bool EXCLUDE_INPUT_LIST=False; /* Option c */
   nco_bool EXTRACT_ALL_COORDINATES=False; /* Option c */
   nco_bool EXTRACT_ASSOCIATED_COORDINATES=True; /* Option C */
@@ -155,6 +154,8 @@ main(int argc,char **argv)
 
   cnk_sct cnk; /* [sct] Chunking structure */
 
+  cnv_sct *cnv; /* [sct] Convention structure */
+
 #if defined(__cplusplus) || defined(PGI_CC)
   ddra_info_sct ddra_info;
   ddra_info.flg_ddra=False;
@@ -187,29 +188,29 @@ main(int argc,char **argv)
   int in_id_1;  
   int in_id_2;  
   int lmt_nbr=0; /* Option d. NB: lmt_nbr gets incremented */
+  int log_lvl=0; /* [enm] netCDF library debugging verbosity [0..5] */
   int md_open; /* [enm] Mode flag for nc_open() call */
-
-  int nbr_glb_att_1;  /* [nbr] Number of global attributes in file */
-  int nbr_glb_att_2;  /* [nbr] Number of global attributes in file */
-  int nbr_grp_att_1;  /* [nbr] Number of group attributes in file */
-  int nbr_grp_att_2;  /* [nbr] Number of group attributes in file */
-  int nbr_att_var_1;  /* [nbr] Number of variable attributes in file */
-  int nbr_att_var_2;  /* [nbr] Number of variable attributes in file */
-  int nbr_dmn_fl_1;   /* [nbr] Number of dimensions in file */
-  int nbr_dmn_fl_2;   /* [nbr] Number of dimensions in file */
-  int nbr_rec_fl_1;   /* [nbr] Number of record dimensions in file */
-  int nbr_rec_fl_2;   /* [nbr] Number of record dimensions in file */
-  int grp_dpt_fl_1;   /* [nbr] Maximum group depth (root = 0) */
-  int grp_dpt_fl_2;   /* [nbr] Maximum group depth (root = 0) */ 
+  int nbr_glb_att_1; /* [nbr] Number of global attributes in file */
+  int nbr_glb_att_2; /* [nbr] Number of global attributes in file */
+  int nbr_grp_att_1; /* [nbr] Number of group attributes in file */
+  int nbr_grp_att_2; /* [nbr] Number of group attributes in file */
+  int nbr_att_var_1; /* [nbr] Number of variable attributes in file */
+  int nbr_att_var_2; /* [nbr] Number of variable attributes in file */
+  int nbr_dmn_fl_1; /* [nbr] Number of dimensions in file */
+  int nbr_dmn_fl_2; /* [nbr] Number of dimensions in file */
+  int nbr_rec_fl_1; /* [nbr] Number of record dimensions in file */
+  int nbr_rec_fl_2; /* [nbr] Number of record dimensions in file */
+  int grp_dpt_fl_1; /* [nbr] Maximum group depth (root = 0) */
+  int grp_dpt_fl_2; /* [nbr] Maximum group depth (root = 0) */ 
   int grp_lst_in_nbr=0; /* [nbr] Number of groups explicitly specified by user */
-  int nbr_grp_fl_1;   /* [nbr] Number of groups in file */
-  int nbr_grp_fl_2;   /* [nbr] Number of groups in file */
-  int var_udt_fl_1;   /* [nbr] Number of non-atomic variables in file */
-  int var_udt_fl_2;   /* [nbr] Number of non-atomic variables in file */
-  int nbr_var_fl_1;   /* [nbr] Number of atomic-type variables in file */
-  int nbr_var_fl_2;   /* [nbr] Number of atomic-type variables in file */
-  int nbr_gpe_nm;     /* [nbr] Number of GPE entries */ 
-  int nbr_cmn_nm=0;     /* [nbr] Number of common entries */
+  int nbr_grp_fl_1; /* [nbr] Number of groups in file */
+  int nbr_grp_fl_2; /* [nbr] Number of groups in file */
+  int var_udt_fl_1; /* [nbr] Number of non-atomic variables in file */
+  int var_udt_fl_2; /* [nbr] Number of non-atomic variables in file */
+  int nbr_var_fl_1; /* [nbr] Number of atomic-type variables in file */
+  int nbr_var_fl_2; /* [nbr] Number of atomic-type variables in file */
+  int nbr_gpe_nm; /* [nbr] Number of GPE entries */ 
+  int nbr_cmn_nm=0; /* [nbr] Number of common entries */
   int nco_op_typ=nco_op_nil; /* [enm] Operation type */
   int opt;
   int out_id;  
@@ -446,7 +447,11 @@ main(int argc,char **argv)
 	nco_exit(EXIT_SUCCESS);
       } /* endif "help" */
       if(!strcmp(opt_crr,"hpss_try")) HPSS_TRY=True; /* [flg] Search HPSS for unfound files */
-      if(!strcmp(opt_crr,"log_lvl") || !strcmp(opt_crr,"log_level")){nc_set_log_level(optarg);} /* [enm] netCDF library debugging verbosity [0..5] */
+      if(!strcmp(opt_crr,"log_lvl") || !strcmp(opt_crr,"log_level")){
+	log_lvl=(int)strtol(optarg,&sng_cnv_rcd,NCO_SNG_CNV_BASE10);
+	if(*sng_cnv_rcd) nco_sng_cnv_err(optarg,"strtol",sng_cnv_rcd);
+	nc_set_log_level(log_lvl);
+      } /* !log_lvl */
       if(!strcmp(opt_crr,"msa_usr_rdr") || !strcmp(opt_crr,"msa_user_order")) MSA_USR_RDR=True; /* [flg] Multi-Slab Algorithm returns hyperslabs in user-specified order */
       if(!strcmp(opt_crr,"ppc") || !strcmp(opt_crr,"precision_preserving_compression") || !strcmp(opt_crr,"quantize")){
         ppc_arg[ppc_nbr]=(char *)strdup(optarg);
@@ -669,11 +674,11 @@ main(int argc,char **argv)
     if(fl_out_fmt != NC_FORMAT_NETCDF4) (void)fprintf(stderr,"%s: WARNING Group Path Edit (GPE) requires netCDF4 output format in most cases (except flattening) but user explicitly requested output format = %s. This command will fail if the output file requires netCDF4 features like groups or netCDF4 atomic types (e.g., NC_STRING, NC_UBYTE...).\n",nco_prg_nm_get(),nco_fmt_sng(fl_out_fmt));
   } /* !gpe */
 
-  /* Is this a CCM/CCSM/CF-format history tape? */
-  CNV_CCM_CCSM_CF=nco_cnv_ccm_ccsm_cf_inq(in_id_1);
+  /* Determine conventions (ARM/CCM/CCSM/CF/MPAS) for treating file */
+  cnv=nco_cnv_ini(in_id_1);
 
   /* Group broadcating (DEFINE mode, True as flg_dfn parameter) */
-  (void)nco_grp_brd(in_id_1,in_id_2,out_id,&cnk,dfl_lvl,gpe,gpe_nm,nbr_gpe_nm,CNV_CCM_CCSM_CF,nco_op_typ,trv_tbl_1,trv_tbl_2,(nco_bool)True);
+  (void)nco_grp_brd(in_id_1,in_id_2,out_id,&cnk,dfl_lvl,gpe,gpe_nm,nbr_gpe_nm,cnv,nco_op_typ,trv_tbl_1,trv_tbl_2,(nco_bool)True);
 
   /* Copy global attributes from file 1 */
   (void)nco_att_cpy(in_id_1,out_id,NC_GLOBAL,NC_GLOBAL,(nco_bool)True);
@@ -695,7 +700,7 @@ main(int argc,char **argv)
   } /* hdr_pad */
 
   /* Group broadcating (WRITE mode, False as flg_dfn parameter) */
-  (void)nco_grp_brd(in_id_1,in_id_2,out_id,&cnk,dfl_lvl,gpe,gpe_nm,nbr_gpe_nm,CNV_CCM_CCSM_CF,nco_op_typ,trv_tbl_1,trv_tbl_2,(nco_bool)False);
+  (void)nco_grp_brd(in_id_1,in_id_2,out_id,&cnk,dfl_lvl,gpe,gpe_nm,nbr_gpe_nm,cnv,nco_op_typ,trv_tbl_1,trv_tbl_2,(nco_bool)False);
 
   /* Close input netCDF files */
   for(thr_idx=0;thr_idx<thr_nbr;thr_idx++) nco_close(in_id_1_arr[thr_idx]);
