@@ -238,6 +238,7 @@ extern "C" {
   char *nco_prg_nm_get(void);
   int nco_prg_id_get(void);
   unsigned short nco_baa_cnv_get(void);
+  unsigned short nco_bnr_cnv_get(void);
   unsigned short nco_dbg_lvl_get(void);
   unsigned short nco_fmt_xtn_get(void);
   unsigned short nco_mrd_cnv_get(void);
@@ -264,6 +265,9 @@ extern "C" {
   unsigned short nco_baa_cnv=0; /* [enm] Bit-Adjustment Algorithm */
   unsigned short nco_baa_cnv_get(void){return nco_baa_cnv;} /* [enm] Bit-Adjustment Algorithm */
 
+  unsigned short nco_bnr_cnv=0; /* [enm] Binary byte-ordering convention to produce (native or byte-swapped) */
+  unsigned short nco_bnr_cnv_get(void){return nco_bnr_cnv;} /* [enm] Binary byte-ordering convention to employ */
+
   unsigned short nco_dbg_lvl=0; /* [enm] Debugging level */
   unsigned short nco_dbg_lvl_get(void){return nco_dbg_lvl;} /* [enm] Debugging level */
 
@@ -344,7 +348,7 @@ extern "C" {
 # define NCO_VERSION_MINOR 7
 #endif /* !NCO_VERSION_MINOR */
 #ifndef NCO_VERSION_PATCH
-# define NCO_VERSION_PATCH 6
+# define NCO_VERSION_PATCH 8
 #endif /* !NCO_VERSION_PATCH */
 #ifndef NCO_VERSION_NOTE
 # define NCO_VERSION_NOTE "" /* Blank for final versions, non-blank (e.g., "-beta37") for pre-release versions */
@@ -354,7 +358,7 @@ extern "C" {
 # define NCO_LIB_VERSION ( NCO_VERSION_MAJOR * 100 + NCO_VERSION_MINOR * 10 + NCO_VERSION_PATCH )
 #endif /* !NCO_LIB_VERSION */
 #ifndef NCO_VERSION
-# define NCO_VERSION "4.7.6"
+# define NCO_VERSION "4.7.8"
 #endif /* !NCO_VERSION */
 
 /* Compatibility tokens new to netCDF4 netcdf.h: */
@@ -717,6 +721,11 @@ extern "C" {
     nco_baa_set, /* 2 Bit Set (option since 20160117) */
   }; /* end nco_baa_cnv */
 
+  enum nco_bnr_cnv{ /* [enm] Binary byte-ordering convention to employ (native or byte-swapped) */
+    nco_bnr_ntv, /* 0 Write native byte-order of host machine (write big- and little-endian on big- and little-endian machines, respectively) */
+    nco_bnr_bsa, /* 1 Use byte-swap algorithm and write non-native order (write little- and big-endian on big- and little-endian machines, respectively) */
+  }; /* end nco_bnr_cnv */
+
   enum nco_upk_cnv{ /* [enm] Unpacking convention to utilize */
     /* netCDF convention  : http://www.unidata.ucar.edu/software/netcdf/docs/netcdf/Attribute-Conventions.html
        HDF/NASA convention: http://modis-atmos.gsfc.nasa.gov/MOD08_D3/faq.html */
@@ -845,6 +854,14 @@ extern "C" {
 
   } lmt_sct;
   
+  /* Convention structure */
+  typedef struct{ /* cnv_sct */
+    nco_bool CCM_CCSM_CF; /* "CF" in "Conventions" attribute */
+    nco_bool MPAS; /* "MPAS" in "Conventions" attribute */
+    nco_bool Group; /* "Groups" in "Conventions" attribute */
+    float cf_vrs; /* [enm] CF-Version */
+  } cnv_sct;
+  
   /* Name ID structure */
   typedef struct{ /* nm_id_sct */
     char *nm; /* Variable (stub name) */
@@ -1021,6 +1038,12 @@ extern "C" {
     nco_grd_2D_unk, /* Unknown or unclassified, POP displaced-pole */
   } nco_grd_2D_typ_enm;
 
+  typedef enum nco_grd_lat_drc_enm{ /* [enm] Latitude direction enum */
+    nco_grd_lat_drc_nil=0,
+    nco_grd_lat_drc_s2n, /* South-to-North: Everything but ERAI, ERA5 */ 
+    nco_grd_lat_drc_n2s, /* North-to-South: Used by ERAI, ERA5 */
+  } nco_grd_lat_drc_enm;
+
   typedef enum nco_grd_lat_typ_enm{ /* [enm] Latitude grid-type enum */
     nco_grd_lat_nil=0,
     nco_grd_lat_unk, /* Unknown or unclassified latitude grid type (e.g., curvilinear) */ 
@@ -1157,6 +1180,7 @@ extern "C" {
     long lat_nbr; /* [nbr] Number of latitudes in destination grid */
     long lon_nbr; /* [nbr] Number of longitudes in destination grid */
     nco_grd_2D_typ_enm grd_typ; /* [enm] Destination grid-type enum */
+    nco_grd_lat_drc_enm lat_drc; /* [enm] Latitude grid-direction enum */
     nco_grd_lat_typ_enm lat_typ; /* [enm] Latitude grid-type enum */
     nco_grd_lon_typ_enm lon_typ; /* [enm] Longitude grid-type enum */
     // Other internal data and metadata 
