@@ -649,16 +649,15 @@ nco_is_sz_rnk_prv_rth_opr /* [fnc] Is program size and rank-preserving arithmeti
      Concatenators (ncrcat, ncecat) are not arithmetic because they just glue data
      Permutor (ncpdq) _is not_ arithmetic because it only re-arranges values
      Packer (ncpdq) _is_ arithmetic because it uses floating point arithmetic to re-represent values
-     nco_pck_plc flag is required as input and used only to distinguish between ncpdq packing and permuting.
+     nco_pck_plc flag is required as input and used only to distinguish between ncpdq packing and permuting
      Attributors (ncrename, ncatted) are not arithmetic because they change metadata, not data
      Averager ncwa is clearly not size or rank-preserving
-     Averager ncra preserves numeric rank though not record-dimension size and so is so is not size and rank-preserving.
-     One use of nco_is_sz_rnk_prv_rth_opr() is to tell which operators should
-     not process multidimensional coordinate values.
+     Averager ncra preserves numeric rank though not record-dimension size and so is so is not size and rank-preserving
+     One use of nco_is_sz_rnk_prv_rth_opr() is to tell which operators should not process multidimensional coordinate values
      For example, we want ncwa to act on coordinates that are reduced 
-     However, we do not want ncfe, ncbo, or ncflint, for example, to load and process single or multi-dimensional coordinate variables.
-     Nor do we want ncpdq to pack variables like gaussian weights, or area since that causes a significant loss of arithmetic precision when those are used as weights in re-inflated files.
-     Such variables to these operators are best treated as "fixed" variables to be copied directly from the input to the output file. */ 
+     However, we do not want ncfe, ncbo, or ncflint, for example, to load and process single or multi-dimensional coordinate variables
+     Nor do we want ncpdq to pack variables like gaussian weights, or area since that causes a significant loss of arithmetic precision when those are used as weights in re-inflated files
+     Such variables to these operators are best treated as "fixed" variables to be copied directly from the input to the output file */ 
   switch(nco_prg_id){
   case ncap: 
   case ncbo:
@@ -798,7 +797,12 @@ nco_cnf_prn(void) /* [fnc] Print NCO configuration and help text */
 		"No",
 #endif /* !NC_64BIT_OFFSET */
 #if defined(NC_LIB_VERSION) && (NC_LIB_VERSION >= 440)
+# if defined(NC_HAS_CDF5) && (NC_HAS_CDF5 != 0)
+		/* 20180916: Simple version test is insufficient since --enable-cdf5 required for netCDF 4.5.x-4.6.1 */
 		"Yes",
+# else /* !NC_HAS_CDF5 */
+		"No",
+# endif /* !NC_HAS_CDF5 */
 #else /* !NC_64BIT_DATA */
 		"No",
 #endif /* !NC_64BIT_DATA */
@@ -838,7 +842,7 @@ nco_nmn_get(void) /* [fnc] Return mnemonic that describes current NCO version */
 { 
   /* Purpose: Return mnemonic describing current NCO version
      Always include terminal \n so mnemonic does not dangle */
-  return "Mnemonic: Honaunau\n";
+  return "Mnemonic: Paradise Lost\n";
 } /* end nco_nmn_get() */
 
 char * /* O [sng] nm_in stripped of any path (i.e., program name stub) */ 
@@ -1040,7 +1044,7 @@ nco_usg_prn(void)
     else if(prg_lcl == ncra || prg_lcl == ncrcat) (void)fprintf(stdout,"-d, --dmn, --dimension dim,[min][,[max][[[,stride[,subcycle]]]]] Dimension's limits, stride, subcycle in hyperslab\n");
     else (void)fprintf(stdout,"-d, --dmn, --dimension dim,[min][,[max]][,[stride]] Dimension's limits and stride in hyperslab\n");
   } /* end if -d */
-  if(strstr(opt_sng,"--dbl|flt")) (void)fprintf(stdout,"    --dbl, --flt, --rth_dbl|flt\tdbl: Always promote single- to double-precision b4 arithmetic (default). flt: OK with single-precision arithmetic.\n");
+  if(strstr(opt_sng,"--dbl|flt")) (void)fprintf(stdout,"    --dbl, --flt, --rth_dbl|flt\tdbl: Promote single- to double-precision b4 arithmetic (default). flt: Single-precision arithmetic is allowed.\n");
   if(strstr(opt_sng,"--dt_fmt")) (void)fprintf(stdout,"    --dt_fmt, --date_format\tPrint UDUnits-compatible dates/times in short, regular, or ISO8601 calendar format (fmt=1,2,3)\n");
   if(strstr(opt_sng,"[-F]")) (void)fprintf(stdout,"-F, --ftn, --fortran\tFortran indexing conventions (1-based) for I/O\n");
   if(strstr(opt_sng,"[-f]")) (void)fprintf(stdout,"-f, --fnc_tbl, --prn_fnc_tbl\tPrint function table\n");
@@ -1081,7 +1085,7 @@ nco_usg_prn(void)
   if(strstr(opt_sng,"[-M")){
     if(prg_lcl == ncecat) (void)fprintf(stdout,"-M, --no_glb_mtd\tSuppress (do not copy) global metadata\n");
     if(prg_lcl == ncks) (void)fprintf(stdout,"-M, --Mtd, --Metadata\tToggle printing global metadata\n");
-    if(prg_lcl == ncpdq) (void)fprintf(stdout,"-M, --pck_map, --pack_map, --map pck_map\tPack map [flt_sht,flt_byt,hgh_sht,hgh_byt,nxt_lsr]\n");
+    if(prg_lcl == ncpdq) (void)fprintf(stdout,"-M, --pck_map, --pack_map, --map pck_map\tPack map [flt_sht,flt_byt,hgh_sht,hgh_byt,nxt_lsr,dbl_flt]\n");
     if(prg_lcl == ncwa) (void)fprintf(stdout,"-M, --msk_val, --mask-value, --mask_value mask_val\tMasking value (default is 1.0)\n");
   } /* end if */
   if(strstr(opt_sng,"[-m")){
